"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDeployArguments = exports.isJSFile = exports.isCSSFile = exports.isNonEmptyString = exports.isAllowedCommandType = void 0;
const isAllowedCommandType = (value) => ['deploy'].includes(value);
exports.isAllowedCommandType = isAllowedCommandType;
const isNonEmptyString = (value) => typeof value === 'string' && value.length > 0;
exports.isNonEmptyString = isNonEmptyString;
const isCSSFile = (value) => value.endsWith('.css');
exports.isCSSFile = isCSSFile;
const isJSFile = (value) => value.endsWith('.js');
exports.isJSFile = isJSFile;
const validateDeployArguments = ({ project, page, sourceFilePath, token }) => {
    const errors = [];
    if (!exports.isNonEmptyString(project)) {
        errors.push('project is required');
    }
    if (!exports.isNonEmptyString(page)) {
        errors.push('page is required');
    }
    if (!exports.isNonEmptyString(sourceFilePath)) {
        errors.push('filepath is required');
    }
    if (!(exports.isCSSFile(sourceFilePath) || exports.isJSFile(sourceFilePath))) {
        errors.push('file type is not css or js');
    }
    if (!exports.isNonEmptyString(token)) {
        errors.push('token is required');
    }
    return errors;
};
exports.validateDeployArguments = validateDeployArguments;
//# sourceMappingURL=util.js.map