"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchWindowHistoryApiAndGetEventStream = void 0;
const rxjs_1 = require("rxjs");
let originalPushState;
let originalReplaceState;
let stream;
const isPatchedOnce = () => stream !== undefined;
const getData = () => ({
    state: window.history.state,
    title: window.document.title,
    url: window.document.documentURI,
});
const extendedPushState = (state, title, url) => {
    // NOTE: use call(window.history) to avoid `TypeError: Illegal invocation`
    originalPushState.call(window.history, state, title, url);
    stream.next({ type: 'pushState', data: getData(), debug: { state, title, url } });
};
const extendedReplaceState = (state, title, url) => {
    // NOTE: use call(window.history) to avoid `TypeError: Illegal invocation`
    originalReplaceState.call(window.history, state, title, url);
    stream.next({ type: 'replaceState', data: getData(), debug: { state, title, url } });
};
const patchWindowHistoryApiAndGetEventStream = () => {
    if (isPatchedOnce()) {
        return stream;
    }
    stream = new rxjs_1.Subject();
    originalPushState = window.history.pushState;
    originalReplaceState = window.history.replaceState;
    // NOTE: use bind(window.history) to avoid `TypeError: Illegal invocation`
    window.history.pushState = extendedPushState.bind(window.history);
    window.history.replaceState = extendedReplaceState.bind(window.history);
    window.addEventListener('popstate', (ev) => stream.next({ type: 'popstate', data: getData(), debug: { state: ev.state } }));
    return stream;
};
exports.patchWindowHistoryApiAndGetEventStream = patchWindowHistoryApiAndGetEventStream;
//# sourceMappingURL=patch-window-history-api-and-get-event-stream.js.map