"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getScrapboxClient = void 0;
const env_1 = require("./common/env");
const rest_api_client_1 = require("./rest-api-client/rest-api-client");
const scrapbox_client_1 = require("./scrapbox-client");
const websocket_client_1 = require("./websocket-clinet/websocket-client");
// singleton instance
let globalClient;
const getScrapboxClient = async (config) => {
    if (globalClient) {
        return globalClient;
    }
    // NOTE: in browser, cookie is used automatically
    if (!env_1.isBrowser() && config.token == '') {
        throw new Error('token required if node environment');
    }
    const apiClient = new rest_api_client_1.RestApiClient(config.token);
    const [user, project] = await Promise.all([apiClient.getMe(), apiClient.getProject(config.projectName)]);
    if (user.id == '') {
        throw new Error('token maybe unauthorized');
    }
    if (project.id == '') {
        throw new Error('project name maybe incorrect');
    }
    globalClient = new Promise((resolve) => {
        resolve(new scrapbox_client_1.ScrapboxClient(user, project, new rest_api_client_1.RestApiClient(config.token), new websocket_client_1.WebsocketClient({ token: config.token })));
    });
    return globalClient;
};
exports.getScrapboxClient = getScrapboxClient;
//# sourceMappingURL=get-singleton.js.map