"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RestApiClient = exports.isNotLoggedInError = exports.isObject = void 0;
const http_client_1 = require("./http-client");
const baseURL = 'https://scrapbox.io/api';
const isObject = (data) => typeof data === 'object' && data !== null;
exports.isObject = isObject;
const isNotLoggedInError = (data) => exports.isObject(data) && data['name'] === 'NotLoggedInError';
exports.isNotLoggedInError = isNotLoggedInError;
class RestApiClient {
    constructor(token, httpClient = new http_client_1.DefaultHttpClient()) {
        this.token = token;
        this.httpClient = httpClient;
    }
    async getPage(projectName, pageName) {
        return this.request(`${baseURL}/pages/${encodeURIComponent(projectName)}/${encodeURIComponent(pageName)}?followRename=true`);
    }
    async getProject(projectName) {
        return this.request(`${baseURL}/projects/${encodeURIComponent(projectName)}`);
    }
    async getMe() {
        return this.request(`${baseURL}/users/me`);
    }
    async request(url) {
        const result = await this.httpClient.get(url, {
            headers: {
                Cookie: `connect.sid=${this.token}`,
            },
        });
        if (exports.isNotLoggedInError(result)) {
            throw new Error('NotLoggedInError');
        }
        return result;
    }
}
exports.RestApiClient = RestApiClient;
//# sourceMappingURL=rest-api-client.js.map