import { ID } from '../../common';
import { CommitChange } from './request';
declare type Error = {
    message: string;
    name: string;
    value: string;
    kind: 'required' | 'ObjectId' | string;
    path: '_id' | 'title' | string;
    stack: string;
};
export declare type CommitError = Error & {
    properties: {
        message: string;
        type: 'required';
        path: 'title';
        value: '';
    };
};
export declare type JoinError = Error & {
    stringValue: string;
};
export declare type CommitErrorResponse = {
    error: {
        name: string;
        message: string;
        errors: {
            title?: CommitError;
            titleLc?: CommitError;
        };
    };
};
export declare type JoinErrorResponse = {
    error: {
        errors: JoinError[];
    };
};
export declare type ErrorResponse = CommitErrorResponse | JoinErrorResponse;
export declare type CommitSuccessResponse = {
    data: {
        commitId: string;
    };
};
export declare type CommitResponse = CommitSuccessResponse | ErrorResponse;
export declare type JoinRoomSuccessResponse = {
    data: {
        success: true;
        pageId: string;
        projectId: string;
    };
};
export declare type JoinRoomResponse = JoinRoomSuccessResponse | ErrorResponse;
export declare type SendResponse = CommitResponse[] | JoinRoomResponse[];
export declare type CursorResponse = [
    'cursor',
    {
        user: {
            id: string;
            displayName: string;
        };
        pageId: string;
        position: {
            line: number;
            char: number;
        };
        visible: true;
        socketId: string;
    }
];
export declare type ExternalCommit = {
    kind: 'page';
    parentId: string;
    changes: CommitChange[];
    cursor: null;
    pageId: string;
    userId: ID;
    projectId: string;
    freeze: true;
    id: string;
};
export declare type ExternalCommitResponse = ['commit', ExternalCommit];
export {};
