"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEventStream = exports.getWebSocket = exports.getNodeJSWebSocket = exports.getBrowserWebSocket = void 0;
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const env_1 = require("../../common/env");
const getBrowserWebSocket = ({ endpoint }) => new WebSocket(endpoint);
exports.getBrowserWebSocket = getBrowserWebSocket;
const getNodeJSWebSocket = ({ endpoint, origin, cookie }) => {
    const NodeWebsocket = require('ws');
    const headers = { Origin: origin, Cookie: cookie };
    return new NodeWebsocket(endpoint, undefined, { headers });
};
exports.getNodeJSWebSocket = getNodeJSWebSocket;
const getWebSocket = (settings) => {
    if (env_1.isBrowser()) {
        // @TODO: validate settings
        return exports.getBrowserWebSocket(settings);
    }
    else {
        // @TODO: validate settings
        return exports.getNodeJSWebSocket(settings);
    }
};
exports.getWebSocket = getWebSocket;
const getEventStream = (socket) => {
    const close = rxjs_1.fromEvent(socket, 'close').pipe(operators_1.first());
    const open = rxjs_1.fromEvent(socket, 'open').pipe(operators_1.takeUntil(close), operators_1.shareReplay());
    const error = rxjs_1.fromEvent(socket, 'error').pipe(operators_1.takeUntil(close), operators_1.shareReplay());
    const message = rxjs_1.fromEvent(socket, 'message').pipe(operators_1.takeUntil(close));
    return { open, close, error, message };
};
exports.getEventStream = getEventStream;
//# sourceMappingURL=websocket.js.map