"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHistoryEventObservable = void 0;
const rxjs_1 = require("rxjs");
const getHistoryEventObservable = (w = window) => {
    return new rxjs_1.Observable((subscriber) => {
        const originPushState = w.history.pushState;
        const originReplaceState = w.history.replaceState;
        const patchedPushState = (state, title, url) => {
            // NOTE: to avoid `TypeError: Illegal invocation`
            originPushState.call(w.history, state, title, url);
            subscriber.next(w.location.href);
        };
        const patchedReplaceState = (state, title, url) => {
            // NOTE: to avoid `TypeError: Illegal invocation`
            originReplaceState.call(w.history, state, title, url);
            subscriber.next(w.location.href);
        };
        const onPopstate = () => subscriber.next(w.location.href);
        w.history.pushState = patchedPushState.bind(w.history);
        w.history.replaceState = patchedReplaceState.bind(w.history);
        w.addEventListener('popstate', onPopstate);
        return () => {
            w.history.pushState = originPushState;
            w.history.replaceState = originReplaceState;
            w.removeEventListener('popstate', onPopstate);
        };
    });
};
exports.getHistoryEventObservable = getHistoryEventObservable;
//# sourceMappingURL=observable.js.map