"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScrapboxClient = void 0;
const rest_api_client_1 = require("./rest-api-client/rest-api-client");
const websocket_client_1 = require("./websocket-clinet/websocket-client");
class ScrapboxClient {
    constructor(token = '', apiClient = new rest_api_client_1.RestApiClient(token), websocketClient = new websocket_client_1.WebsocketClient({ token })) {
        this.apiClient = apiClient;
        this.websocketClient = websocketClient;
    }
    async getPage(projectName, pageName) {
        return this.apiClient.getPage(projectName, pageName);
    }
    async changeLine(projectName, pageName, change) {
        const project = await this.getProject(projectName);
        const { pageId, commitId } = await this.getPageIdAndCommitId(projectName, pageName);
        return this.commit({
            changes: Array.isArray(change) ? change : [change],
            projectId: project.id,
            pageId: pageId,
            commitId: commitId,
        });
    }
    async getUser() {
        return await this.apiClient.getMe();
    }
    async getProject(projectName) {
        return await this.apiClient.getProject(projectName);
    }
    async getPageIdAndCommitId(projectName, pageName) {
        const page = await this.apiClient.getPage(projectName, pageName);
        return { pageId: page.id, commitId: page.commitId };
    }
    async commit(param) {
        const user = await this.getUser();
        // to receive result of commit
        await this.websocketClient.join({ projectId: param.projectId, pageId: param.pageId });
        return this.websocketClient.commit({
            userId: user.id,
            projectId: param.projectId,
            pageId: param.pageId,
            parentId: param.commitId,
            changes: param.changes,
        });
    }
}
exports.ScrapboxClient = ScrapboxClient;
//# sourceMappingURL=scrapbox-client.js.map