"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scrapboxReady = exports.isScrapboxReady = exports.nodeChange = exports.findElementOrFail = void 0;
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const findElementOrFail = (selector, parent = document) => {
    const elem = parent.querySelector(selector);
    if (!elem) {
        throw new Error('Element not found');
    }
    return elem;
};
exports.findElementOrFail = findElementOrFail;
const nodeChange = (node, options) => {
    return new rxjs_1.Observable((subscriber) => {
        const mo = new MutationObserver(() => subscriber.next());
        mo.observe(node, options);
        return () => mo.disconnect();
    }).pipe(operators_1.share());
};
exports.nodeChange = nodeChange;
// NOTE: scrapbox.Project.name is set after react bootstrapped
const isScrapboxReady = () => Boolean(window.scrapbox.Project && window.scrapbox.Project.name);
exports.isScrapboxReady = isScrapboxReady;
const scrapboxReady = () => {
    return new rxjs_1.Observable((subscriber) => {
        const subscription = rxjs_1.timer(0, 30).subscribe(() => {
            if (exports.isScrapboxReady()) {
                subscriber.next(window.scrapbox);
                subscriber.complete();
                subscription.unsubscribe();
            }
        });
        return subscription;
    });
};
exports.scrapboxReady = scrapboxReady;
//# sourceMappingURL=util.js.map